TestStepExecutor class

Translates declarative TestSteps into widget actions or assertions.

Constructors

TestStepExecutor({required WidgetTester tester, required EnsembleTestContext context, required AssertionEngine assertions, required EnsembleTestHarness harness, EnsembleConfig? config, TestExecutionConfig? executionConfig})

Properties

assertions AssertionEngine
final
config TestExecutionConfig
final
context EnsembleTestContext
final
harness EnsembleTestHarness
final
hashCode int
The hash code for this object.
no setterinherited
onAfterActionStep FutureOr<void> Function(TestStep step)?
getter/setter pair
onBeforeActionStep FutureOr<void> Function(TestStep step)?
getter/setter pair
onWaitForNavigationMatched FutureOr<void> Function(TestStep step)?
getter/setter pair
onWaitForTextMatched FutureOr<void> Function(TestStep step)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tester WidgetTester
final

Methods

enterTextOn(String id, String value) Future<void>
execute(TestStep step) Future<void>
focusWidget(String id) Future<void>
longPressWidget(String id) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openScreenByName(String screen) Future<void>
requireId(TestStep step) String
settle({Duration? timeout}) Future<void>
tapWidget(String id, {int? timeoutMs}) Future<void>
toString() String
A string representation of this object.
inherited
unfocus() Future<void>
waitForTextContains({String? text, List<String> anyOf = const [], required int timeoutMs}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited