EnsembleTestAppTarget class

App target resolved from ensemble/ensemble-config.yaml (definitions.local).

Constructors

EnsembleTestAppTarget({required String appPath, required String appHome, String? i18nPath})
const

Properties

appHome String
final
appPath String
final
hashCode int
The hash code for this object.
no setterinherited
i18nPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testsAssetPrefix String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited