EnsembleTestExecutionPlan class

Topologically sorted test run order (each test id appears once).

Constructors

EnsembleTestExecutionPlan({required List<EnsembleTestDefinition> ordered, EnsembleTestConfig config = const EnsembleTestConfig()})
const

Properties

config EnsembleTestConfig
final
hashCode int
The hash code for this object.
no setterinherited
ordered List<EnsembleTestDefinition>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited