EnsembleYamlTestOptions class

Options for runEnsembleYamlTests, typically set from test/ensemble_tests.dart.

Constructors

EnsembleYamlTestOptions({Future<void> bootstrap()?, Map<String, Function>? externalMethods})
const

Properties

bootstrap Future<void> Function()?
App bootstrap, typically () => EnsembleModules().init() from lib/generated/ensemble_modules.dart (same as main.dart).
final
externalMethods Map<String, Function>?
Host-app methods passed to EnsembleApp, e.g. captureCertificateForHost.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited