EnsembleAppInspection class

Constructors

EnsembleAppInspection({required String appDir, required String appPath, required String appHome, required List<ScreenInspection> screens, List<String> widgets = const [], List<String> actions = const [], List<String> scripts = const []})
const

Properties

actions List<String>
final
appDir String
final
appHome String
final
appPath String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screens List<ScreenInspection>
final
scripts List<String>
final
widgets List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toPrettyJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited