mocks/adobe_test_setup library

Functions

ensureAdobeAnalyticsMocksForTest() → void
Installs no-op Adobe Experience Platform method channel handlers so AdobeAnalyticsImpl can initialize under flutter test without native SDKs.