mocks/test_api_provider_overlay library

Classes

APICallRecord
Diagnostic record for one API invocation observed during a test.
ApiCallRecorder
In-memory API call collection used by reports and assertions.
TestApiOverlay
Delegates to a real provider unless host has a test override for the API name.
TestApiProviderOverlay
Test provider overlay: observes API calls, applies test overrides, otherwise delegates. HTTP provider that applies test mocks and delegates all other calls.