ApiCallRecorder class

In-memory API call collection used by reports and assertions.

Constructors

ApiCallRecorder()

Properties

calls List<APICallRecord>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callCount(String apiName) int
callsFor(String apiName) List<APICallRecord>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
record(APICallRecord call) → void
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited