TestApiOverlay class

Delegates to a real provider unless host has a test override for the API name.

Constructors

TestApiOverlay(TestApiProviderOverlay _host, APIProvider _delegate)

Properties

delegate → APIProvider
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() TestApiOverlay
override
dispose() → void
override
init(String appId, Map<String, dynamic> config) Future<void>
override
invokeApi(BuildContext context, YamlMap api, DataContext eContext, String apiName) Future<Response>
override
invokeMockAPI(DataContext eContext, dynamic mock) Future<Response>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited