TestLogger class
Simple in-memory logger for test runs.
Constructors
Properties
Methods
-
clear(
) → void - Clears all lines collected for the current test.
-
log(
String message) → void - Adds a line to the in-memory test log.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeLogFile(
{required String testId, required String name, required String content, String extension = 'log'}) → Future< String>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited