EnsembleSingleTestResult class

Result for one executed YAML test case.

Constructors

EnsembleSingleTestResult({required String testId, Map<String, dynamic> metadata = const {}, required TestStatus status, required int durationMs, int? failedStepIndex, TestStep? failedStep, String? message, String? stackTrace, List<String> logs = const [], EnsembleTestReportDetails? report})
const
EnsembleSingleTestResult.failed({required String testId, Map<String, dynamic> metadata = const {}, required int durationMs, int? failedStepIndex, TestStep? failedStep, String? error, String? stackTrace, List<String> logs = const [], EnsembleTestReportDetails? report})
factory
EnsembleSingleTestResult.passed({required String testId, Map<String, dynamic> metadata = const {}, required int durationMs, List<String> logs = const [], EnsembleTestReportDetails? report})
factory

Properties

durationMs int
final
failedStep TestStep?
final
failedStepIndex int?
final
hashCode int
The hash code for this object.
no setterinherited
logs List<String>
final
message String?
final
metadata Map<String, dynamic>
final
report EnsembleTestReportDetails?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
status TestStatus
final
testId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited