stepDurationsMs property
Wall-clock ms for each top-level step (same order as EnsembleTestCase.steps). Shorter than the step list when the run failed mid-suite.
Implementation
final List<int> stepDurationsMs;
Wall-clock ms for each top-level step (same order as EnsembleTestCase.steps). Shorter than the step list when the run failed mid-suite.
final List<int> stepDurationsMs;