EnsembleTestRunRequest class

Request object describing an Ensemble YAML test run.

Constructors

EnsembleTestRunRequest({String? appPath, String? appHome, String? i18nPath, required List<EnsembleTestCase> tests, EnsembleTestConfig config = const EnsembleTestConfig(), EnsembleTestEnvironment environment = const EnsembleTestEnvironment()})
const

Properties

appHome String?
final
appPath String?
final
config EnsembleTestConfig
final
environment EnsembleTestEnvironment
final
hashCode int
The hash code for this object.
no setterinherited
i18nPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tests List<EnsembleTestCase>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited