MockAPIResponse class

Mock API response returned by the test HTTP provider. A deterministic API response used by the test provider.

responses can provide a sequence of responses for repeated calls, and delayMs simulates server latency while preserving the API loading state.

Constructors

MockAPIResponse({int statusCode = 200, dynamic body, Map<String, dynamic>? headers, int? delayMs, List<MockAPIResponse> responses = const []})
const

Properties

body → dynamic
final
delayMs int?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
responses List<MockAPIResponse>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited