TestDeviceTarget class

One device (+ optional locale/theme) in a suite run matrix.

Constructors

TestDeviceTarget({required String id, required String platform, required String model, String? locale, String? theme})
const

Properties

displayLabel String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
locale String?
final
model String
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme String?
Ensemble theme name or alias (light / darkLight / Dark).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toScreenshotArgs() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited