TestMocks class
Mock configuration attached to a test case. API mocks attached to a test after profile and suite composition.
Constructors
-
TestMocks({Map<
String, MockAPIResponse> apis = const {}}) -
const
Properties
-
apis
→ Map<
String, MockAPIResponse> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited