TestProfile class

A named profile containing reusable mocks and initial state.

Constructors

TestProfile({List<String> mockFiles = const [], Map<String, dynamic> inlineMocks = const {}, Map<String, dynamic> initialState = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialState Map<String, dynamic>
final
inlineMocks Map<String, dynamic>
final
mockFiles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited