TestReporter class

Constructors

TestReporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatFailureSummary(EnsembleTestRunResult result, {Iterable<String> failedPaths = const [], Iterable<Object?> pendingFrameworkExceptions = const []}) String
Formats the short failure passed to Flutter's test framework.
formatSummary(EnsembleTestRunResult result, {String? testFile}) String
Formats a multi-test run report for console output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited