AppSessionSnapshot class

In-memory app state captured from a successful session-producing test.

Constructors

AppSessionSnapshot({required Map<String, dynamic> publicStorage, required Map<String, dynamic> secureStorage, required Map<String, dynamic> keychain, Locale? locale})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keychain Map<String, dynamic>
final
locale Locale?
final
publicStorage Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secureStorage Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

capture() Future<AppSessionSnapshot>