EnsembleTestSetup class

Per-test bootstrap data applied before the widget tree mounts.

Constructors

EnsembleTestSetup({Map<String, dynamic>? envOverrides, Map<String, dynamic>? initialPublicStorage, Map<String, dynamic>? initialSecureStorage, Map<String, dynamic>? initialKeychain})
const

Properties

envOverrides Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
initialKeychain Map<String, dynamic>?
final
initialPublicStorage Map<String, dynamic>?
final
initialSecureStorage Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited