StorageKeyChange class

One public-storage key change during a test step.

Constructors

StorageKeyChange({required String key, required String change, Object? before, Object? after})
const

Properties

after Object?
final
before Object?
final
change String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited