AppFrameTimingEntry class

Constructors

AppFrameTimingEntry({required int frameNumber, required int buildStartMicros, required double buildMs, required double rasterMs, required double vsyncOverheadMs, required double totalSpanMs})
const
AppFrameTimingEntry.fromFrameTiming({required int frameNumber, required FrameTiming timing})
factory

Properties

buildMs → double
final
buildStartMicros → int
final
frameNumber → int
final
hashCode → int
The hash code for this object.
no setterinherited
isJanky → bool
no setter
rasterMs → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSpanMs → double
final
vsyncOverheadMs → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

frameBudgetMs → const double