PerformanceMarker class

Constructors

PerformanceMarker({required String testId, required int? stepIndex, required String label, required String? screen, required String phase, required int startFrame, required int endFrame, required DateTime startTime, required DateTime endTime})
const

Properties

endFrame → int
final
endTime → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
phase → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → String?
final
startFrame → int
final
startTime → DateTime
final
stepIndex → int?
final
testId → String
final

Methods

containsFrame(int frameNumber) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(DateTime timestamp, {Duration tolerance = Duration.zero}) → bool
shiftedFrames(int offset) → PerformanceMarker
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited