ScreenshotSheetFrame class

Constructors

ScreenshotSheetFrame({required int stepIndex, required String label, required Image image, String? deviceId, String? deviceLabel, String? platform, String? model, ScreenshotHighlight? highlight})

Properties

deviceId → String?
final
deviceLabel → String?
final
encodedReportImage ↔ EncodedScreenshotImage?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highlight → ScreenshotHighlight?
final
image → Image
final
label → String
final
model → String?
final
platform → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepIndex → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited