NavigationFlowRecorder class
Records screen visits for YAML tests (including back-navigation revisits).
Constructors
Properties
-
flow
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onScreenAdded
↔ FutureOr<
void> Function(String screenName)? -
Invoked when a screen name is appended to flow (after de-dupe).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginTest(
String? currentScreen) → void -
clear(
) → void -
dispose(
) → void -
flushPending(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordScreenChange(
VisibleScreen? screen) → void - Visible for unit tests; production uses startListening.
-
seed(
Iterable< String> names) → void - For unit tests only.
-
startListening(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited