EnsembleTestSchemaBuilder class

Builds JSON Schema for app-local tests/*.test.yaml files.

Constructors

EnsembleTestSchemaBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build() Map<String, dynamic>
buildConfig() Map<String, dynamic>
buildConfigJson({bool pretty = true}) String
buildJson({bool pretty = true}) String

Constants

configSchemaId → const String
schemaId → const String
schemaVersion → const String