EnsembleTestValidationIssue class

Constructors

EnsembleTestValidationIssue({required ValidationSeverity severity, required String code, required String message, String? path, String? testId})
const

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ValidationSeverity
final
testId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited