EnsembleTestValidationResult class

Properties

hasErrors bool
no setter
hashCode int
The hash code for this object.
no setterinherited
issues List<EnsembleTestValidationIssue>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatText() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPrettyJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited