TestStepArgKind enum

Argument shape for a declarative test step (JSON Schema for editor validation).

Inheritance
Available extensions

Values

empty → const TestStepArgKind
openScreen → const TestStepArgKind
trigger → const TestStepArgKind
idRequired → const TestStepArgKind
idOptional → const TestStepArgKind
enterText → const TestStepArgKind
select → const TestStepArgKind
selectIndex → const TestStepArgKind
setSlider → const TestStepArgKind
chooseValue → const TestStepArgKind
scroll → const TestStepArgKind
swipe → const TestStepArgKind
drag → const TestStepArgKind
pump → const TestStepArgKind
timeoutOptional → const TestStepArgKind
httpRequest → const TestStepArgKind
waitFor → const TestStepArgKind
waitForGone → const TestStepArgKind
waitForNavigation → const TestStepArgKind
textRequired → const TestStepArgKind
textOrAnyOf → const TestStepArgKind
textContains → const TestStepArgKind
expectEquals → const TestStepArgKind
expectChecked → const TestStepArgKind
expectProperty → const TestStepArgKind
expectCount → const TestStepArgKind
expectListCount → const TestStepArgKind
screenRequired → const TestStepArgKind
expectVisited → const TestStepArgKind
apiName → const TestStepArgKind
storageKey → const TestStepArgKind
group → const TestStepArgKind
repeat → const TestStepArgKind
optional → const TestStepArgKind
ifVisible → const TestStepArgKind
setAuth → const TestStepArgKind
setPermission → const TestStepArgKind
setDevice → const TestStepArgKind
setLocale → const TestStepArgKind
setTheme → const TestStepArgKind
runScript → const TestStepArgKind
expectConsoleLog → const TestStepArgKind
expectErrorContains → const TestStepArgKind
expectApiCallOrder → const TestStepArgKind
expectListContains → const TestStepArgKind
expectListItem → const TestStepArgKind
expectBackStack → const TestStepArgKind
expectCanGoBack → const TestStepArgKind
expectSemanticsLabel → const TestStepArgKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
jsonSchema Map<String, dynamic>

Available on TestStepArgKind, provided by the TestStepArgKindSchema extension

JSON Schema for this step's YAML argument object.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TestStepArgKind>
A constant List of the values in this enum, in order of their declaration.