TestStepRegistryEntry class

Single source of truth for declarative test steps (metadata + JSON Schema args).

Constructors

TestStepRegistryEntry({required TestStepCategory category, required TestStepTier tier, required TestStepArgKind argKind, required String description, required Map<String, dynamic> example, String? executorCanonical})
const

Properties

argKind TestStepArgKind
final
category TestStepCategory
final
description String
final
example Map<String, dynamic>
Example YAML args object for this step (also used in JSON Schema).
final
executorCanonical String?
When set, TestStepVocabulary.resolveStepType maps this YAML key here (e.g. waitpump). Schema/definition use this entry's argKind.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tier TestStepTier
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited