ExtendedStepHandlers class
Handlers for the full declarative vocabulary beyond the original MVP set.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
captureScreenshotBytes(
WidgetTester tester, {required DeviceInfo device}) → Future< Uint8List> -
captureScreenshotImage(
WidgetTester tester) → Image -
encodeScreenshotImage(
Image image, DeviceInfo device) → Future< Uint8List> -
tryExecute(
TestStepExecutor executor, TestStep step) → Future< bool>