TestExecutionConfig class

Timing defaults for TestStepExecutor (overridable per executor instance).

Constructors

TestExecutionConfig({Duration settleStepDuration = const Duration(milliseconds: 100), Duration settleTimeout = const Duration(seconds: 10), Duration waitPollInterval = const Duration(milliseconds: 100), Duration defaultWaitTimeout = const Duration(seconds: 5)})
const

Properties

defaultWaitTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settleStepDuration Duration
final
settleTimeout Duration
final
waitPollInterval Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited