AssertionEngine class
Methods
-
activeScope()
→ ScopeManager?
-
-
apiCallSummary({int limit = 10})
→ String
-
-
closestVisibleWidgetIds(String target, {int limit = 5})
→ List<String>
-
-
expectAccessible(String id)
→ void
-
-
expectApiCalled(String apiName, int times)
→ void
-
-
expectApiCallOrder(List<String> names)
→ void
-
-
expectApiNotCalled(String apiName)
→ void
-
-
expectBackStack(List<String> screens)
→ void
-
-
expectCanGoBack(bool expected)
→ void
-
-
expectChecked(String id, bool expected)
→ void
-
-
expectConsoleLog(String contains)
→ void
-
-
expectCount(String id, int expected)
→ void
-
-
expectDisabled(String id)
→ void
-
-
expectEnabled(String id)
→ void
-
-
expectErrorRecorded(String? contains)
→ void
-
-
expectExists(String id)
→ void
-
-
expectLastApiCall(String apiName)
→ void
-
-
expectListContains({required String listId, required String text})
→ void
-
-
expectListCount({required String listId, required int expected, String? itemId, bool atLeast = false})
→ void
-
-
expectNavigateTo(String screenName)
→ void
-
-
expectNoConsoleErrors()
→ void
-
-
expectNoOverflow(String id)
→ void
-
-
expectNoRenderErrors()
→ void
-
-
expectNotExists(String id)
→ void
-
-
expectNoText(String text)
→ void
-
-
expectNoTextAny(List<String> texts)
→ void
-
-
expectNotVisible(String id)
→ void
-
-
expectNotVisited(String screenName)
→ void
-
-
expectProperty(String id, String property, dynamic expected)
→ void
-
-
expectSemanticsLabel(String id, String label)
→ void
-
-
expectStorage(String key, dynamic expected)
→ void
-
-
expectText(String text)
→ void
-
-
expectTextAny(List<String> texts)
→ void
-
-
expectTextContains(String text)
→ void
-
-
expectTextContainsAny(List<String> texts)
→ void
-
-
expectValue(String id, dynamic expected)
→ void
-
-
expectVisible(String id)
→ void
-
-
expectVisited(String screenName)
→ void
-
-
finderForId(String id)
→ Finder
-
-
firstVisuallyActionableElement(Finder finder, {bool requireHitTestable = false})
→ Element?
-
First matching element that is on the current route and visually actionable.
-
isAnyTextContainingVisible(List<String> texts)
→ bool
-
-
isAnyTextVisible(List<String> texts)
→ bool
-
-
isElementVisuallyActionable(Element element)
→ bool
-
Whether
element is on the current modal route, not offstage, and on-screen.
-
isTextContainingVisible(String text)
→ bool
-
-
isTextVisible(String text)
→ bool
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
rectForVisuallyActionable(Finder finder, {bool requireHitTestable = false})
→ Rect?
-
Bounds for firstVisuallyActionableElement, or null when none qualify.
-
textFailureHint(List<String> expectedTexts, {int limit = 10})
→ String
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
visibleTextSummary({int limit = 10})
→ String
-
-
visibleWidgetIdSummary({int limit = 12})
→ String
-
-
widgetIdFailureHint(String id, {int limit = 12})
→ String
-