AssertionEngine class

Constructors

AssertionEngine({required WidgetTester tester, required EnsembleTestContext context})

Properties

context EnsembleTestContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tester WidgetTester
final

Methods

activeScope() → ScopeManager?
apiCallSummary({int limit = 10}) String
expectAccessible(String id) → void
expectApiCalled(String apiName, int times) → void
expectApiCallOrder(List<String> names) → void
expectApiHeader(String apiName, String header, dynamic expected, {int? times}) → void
expectApiNotCalled(String apiName) → void
expectApiRequest(String apiName, {dynamic body, dynamic query, dynamic headers, int? times}) → void
expectApiRequestContains(String apiName, {dynamic body, dynamic query, dynamic headers, int? times}) → void
expectBackStack(List<String> screens) → void
expectCanGoBack(bool expected) → void
expectChecked(String id, bool expected) → void
expectConsoleLog(String contains) → void
expectCount(String id, int expected) → void
expectDisabled(String id) → void
expectEnabled(String id) → void
expectErrorRecorded(String? contains) → void
expectExists(String id) → void
expectLastApiCall(String apiName) → void
expectListContains({required String listId, required String text}) → void
expectListCount({required String listId, required int expected, String? itemId, bool atLeast = false}) → void
expectNavigateTo(String screenName) → void
expectNoConsoleErrors() → void
expectNoOverflow(String id) → void
expectNoRenderErrors() → void
expectNotExists(String id) → void
expectNoText(String text) → void
expectNotVisible(String id) → void
expectNotVisited(String screenName) → void
expectProperty(String id, String property, dynamic expected) → void
expectSemanticsLabel(String id, String label) → void
expectState(String path, dynamic expected) → void
expectStateContains(String path, dynamic contains) → void
expectStateExists(String path) → void
expectStateNotExists(String path) → void
expectStorage(String key, dynamic expected) → void
expectText(String text) → void
expectTextContains(String text) → void
expectValue(String id, dynamic expected) → void
expectVisible(String id) → void
expectVisited(String screenName) → void
finderForId(String id) Finder
matchesState(String path, dynamic expected) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readState(String path) → dynamic
Reads a data-context path without asserting.
toString() String
A string representation of this object.
inherited
visibleWidgetIdSummary({int limit = 20}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited