textFailureHint method
Implementation
String textFailureHint(List<String> expectedTexts, {int limit = 10}) {
final expected = _nonEmptyTexts(expectedTexts);
final localeHint = expected.any(_containsNonAscii)
? ' Also verify that the test is running with the expected locale/translation.'
: '';
return '${visibleTextSummary(limit: limit)} '
'${_currentScreenSummary()} '
'Hint: check that the app is on the expected screen/state before this assertion.$localeHint';
}