YamlTestAppPatcher class

Temporarily wires appDir to run declarative YAML tests, then restores files.

Constructors

YamlTestAppPatcher(String appDir)

Properties

appDir String
final
hashCode int
The hash code for this object.
no setterinherited
hasTestYamlOnDisk bool
no setter
hasTimerRewrites bool
no setter
pubspecChanged bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testsDirPath String?
no setter
testsDirRelative String?
no setter
timerRewriteConfig TimerRewriteConfig
no setter

Methods

enable() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore() → void
rewriteTimersIn(String targetAppDir) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

testEntryContents String
@deprecated Use testEntryContentsFor.
no setter

Static Methods

testEntryContentsFor(String packageName) String
testsAssetLineFor(String testsDirRelative) String

Constants

legacyTestEntryContents → const String
Legacy CLI stub without module bootstrap.
testEntryRelativePath → const String