EnsembleTestDiscovery class
Discovers declarative tests and app settings from the host Flutter app bundle.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
applyDeviceFilter(
EnsembleTestConfig config, Set< String> selectedIds) → EnsembleTestConfig -
Keeps only suite
deviceswhose ids are inselectedIds. -
findConfigYamlAsset(
String testsAssetPrefix) → Future< String?> -
Optional suite-level config bundled as
tests/config.yaml. -
findTestYamlAssets(
String testsAssetPrefix) → Future< List< String> > -
All
*.test.yamlfiles bundled undertestsAssetPrefix. -
loadAppTarget(
) → Future< EnsembleTestAppTarget> -
Reads
definitions.localfromensemble/ensemble-config.yaml. -
loadTestConfig(
String testsAssetPrefix) → Future< EnsembleTestConfig>