EnsembleTestDiscovery class

Discovers declarative tests and app settings from the host Flutter app bundle.

Constructors

EnsembleTestDiscovery()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findTestYamlAssets(String testsAssetPrefix) Future<List<String>>
All *.test.yaml files bundled under testsAssetPrefix.
loadAppTarget() Future<EnsembleTestAppTarget>
Reads definitions.local from ensemble/ensemble-config.yaml.