EnsembleTestExecutionPlanner class
Builds a dependency-ordered execution plan for all declarative tests.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
{EnsembleTestAppTarget? target, EnsembleTestSelection selection = const EnsembleTestSelection()}) → Future< EnsembleTestExecutionPlan> - Discovers assets, parses every file, validates graph, returns run order.
-
orderIdsForTest(
Map< String, EnsembleTestDefinition> byId) → List<String> - Exposed for unit tests only.
-
selectAndOrderIdsForTest(
Map< String, EnsembleTestDefinition> byId, EnsembleTestSelection selection) → List<String>