ScreenInspection class
Constructors
-
ScreenInspection({required String name, required String path, List<
String> imports = const [], List<String> testIds = const [], List<String> apis = const [], List<String> actions = const [], List<String> storageReferences = const [], List<String> envReferences = const [], List<String> lifecycle = const []}) -
const
Properties
-
actions
→ List<
String> -
final
-
apis
→ List<
String> -
final
-
envReferences
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ List<
String> -
final
-
lifecycle
→ List<
String> -
final
- name → String
-
final
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storageReferences
→ List<
String> -
final
-
testIds
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited