APICallRecord class

Diagnostic record for one API invocation observed during a test.

Constructors

APICallRecord({required String name, required YamlMap apiDefinition, required DateTime timestamp, int? stepIndex, bool? mocked, int? statusCode, String? error, Object? responseBody, String? type, String? resolvedUrl, Map<String, dynamic>? resolvedHeaders, Map<String, dynamic>? resolvedParameters, dynamic resolvedBody})

Properties

apiDefinition → YamlMap
final
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mocked bool?
getter/setter pair
name String
final
resolvedBody ↔ dynamic
getter/setter pair
resolvedHeaders Map<String, dynamic>?
getter/setter pair
resolvedParameters Map<String, dynamic>?
getter/setter pair
resolvedUrl String?
getter/setter pair
responseBody Object?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
getter/setter pair
stepIndex int?
Top-level step index (0-based) active when the call started, if any.
final
timestamp DateTime
final
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited