EnsembleTestCase class

Parsed definition of a single YAML test case.

Constructors

EnsembleTestCase({required String id, String? sourcePath, String? type, String? feature, List<String> tags = const [], String? description, String? owner, String? priority, bool parallel = true, int retry = 0, String? startScreen, Map<String, dynamic> startScreenInputs = const {}, String? session, String? profile, List<String> profiles = const [], String? scenarioId, String? scenarioDescription, List<String> mockFiles = const [], Map<String, dynamic> inlineMocks = const {}, List<TestScenario> scenarios = const [], Map<String, dynamic> initialState = const {}, List<TestStep> setupSteps = const [], TestMocks mocks = const TestMocks(), required List<TestStep> steps, TestDeviceTarget? deviceTarget, String? screenshotSheetId})
const

Properties

description String?
final
deviceTarget TestDeviceTarget?
Set when suite devices expands this test for one device.
final
feature String?
final
hashCode int
The hash code for this object.
no setterinherited
hasSession bool
no setter
hasStartScreen bool
no setter
id String
final
initialState Map<String, dynamic>
final
inlineMocks Map<String, dynamic>
final
metadataJson Map<String, dynamic>
no setter
mockFiles List<String>
final
mocks TestMocks
Runtime API mocks resolved from mockFiles.
final
owner String?
final
parallel bool
final
priority String?
final
profile String?
final
profiles List<String>
final
resolvedScreenshotSheetId String
Contact sheet filename / aggregation key.
no setter
retry int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioDescription String?
final
scenarioId String?
final
scenarios List<TestScenario>
final
screenshotSheetId String?
Optional contact-sheet filename key (defaults to id).
final
session String?
Test id whose captured storage state is restored before startScreen.
final
setupSteps List<TestStep>
Headless actions executed before the start screen is mounted.
final
sourcePath String?
final
startScreen String?
Cold-start screen.
final
startScreenInputs Map<String, dynamic>
final
steps List<TestStep>
final
tags List<String>
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited