EnsembleTestCase class
Parsed definition of a single YAML test case.
Constructors
-
EnsembleTestCase({required String id, String? sourcePath, String? type, String? feature, List<
String> tags = const [], String? description, String? owner, String? priority, String? startScreen, String? prerequisite, Map<String, dynamic> initialState = const {}, TestMocks mocks = const TestMocks(), required List<TestStep> steps}) -
const
Properties
- description → String?
-
final
- feature → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPrerequisite → bool
-
no setter
- hasStartScreen → bool
-
no setter
- id → String
-
final
-
initialState
→ Map<
String, dynamic> -
final
-
metadataJson
→ Map<
String, dynamic> -
no setter
- mocks → TestMocks
-
final
- owner → String?
-
final
- prerequisite → String?
-
Test id that must run before this one (same app session).
final
- priority → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcePath → String?
-
final
- startScreen → String?
-
Cold-start screen. Omit when prerequisite is set.
final
-
steps
→ List<
TestStep> -
final
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited