EnsembleTestReportDetails class

Human-readable run metadata for console reports (see TestReporter).

Constructors

EnsembleTestReportDetails({required String startScreen, String? endScreen, String? prerequisite, List<String> screensVisited = const [], List<String> stepsOutline = const []})
const

Properties

endScreen String?
final
hashCode int
The hash code for this object.
no setterinherited
prerequisite String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screensVisited List<String>
final
startScreen String
Display start screen (explicit or inherited from runtime).
final
stepsOutline List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited