EnsembleTestRunResult class
Aggregate result for a YAML test run. Aggregate result for one complete runner invocation.
Constructors
-
EnsembleTestRunResult({required List<
EnsembleSingleTestResult> results, List<String> suiteLogs = const []}) -
const
Properties
- failedCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- passedCount → int
-
no setter
-
results
→ List<
EnsembleSingleTestResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suiteLogs
→ List<
String> -
final
- summary → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited