MockAPIResponse class

Mock API response returned by the test HTTP provider.

Constructors

MockAPIResponse({int statusCode = 200, dynamic body, Map<String, dynamic>? headers, int? delayMs})
const

Properties

body → dynamic
final
delayMs int?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited