ScreenshotConfig class

Controls automatic per-step screenshot capture and filtering.

Constructors

ScreenshotConfig({bool enabled = false, List<String> includeSteps = const [], List<String> excludeSteps = const []})
const

Properties

enabled bool
final
excludeSteps List<String>
final
hashCode int
The hash code for this object.
no setterinherited
includeSteps List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldCaptureStep(String stepType) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited