TestScenario class
One scenario from a scenario-based test suite.
Scenarios share the test's steps while providing different variables and mock inputs. The runner expands them into independent test results.
Constructors
-
TestScenario({required String id, String? description, Map<
String, dynamic> vars = const {}}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited