TestServiceConfig class

A local process that the runner starts before executing tests.

Constructors

TestServiceConfig({required String name, required String command, String? url, List<String> arguments = const [], String? workingDirectory, Map<String, String> environment = const {}, String? readyUrl, int readyTimeoutMs = 10000})
const

Properties

arguments List<String>
final
command String
final
environment Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
readyTimeoutMs int
final
readyUrl String?
final
resolvedEnvironment Map<String, String>
no setter
resolvedReadyUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final
workingDirectory String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited