TestStep class
Single executable step from a YAML test file.
Constructors
Properties
-
args
→ Map<
String, dynamic> -
final
- canonicalType → String
-
Canonical handler name after alias resolution.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nestedSteps
→ List<
TestStep> -
Nested steps for control-flow step types such as
groupandrepeat.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
YAML step key (e.g.
expectVisible,group).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
withCanonicalType(
String canonical) → TestStep
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited