TimerRewriteConfig class

Controls timer normalization used by the Flutter test host.

Constructors

TimerRewriteConfig({bool enabled = false, int maxStartAfterSeconds = 1, int maxRepeatIntervalSeconds = 1})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
maxRepeatIntervalSeconds int
final
maxStartAfterSeconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited