EnsembleTestParser class
Parses test cases and suite configuration from YAML.
The parser is useful for tooling that wants to validate or inspect test definitions without starting Flutter. Runtime execution is provided by runEnsembleYamlTests.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseConfigString(
String content, {String? sourcePath}) → EnsembleTestConfig -
Parses one suite
tests/config.yamldocument fromcontent. -
parseFile(
String path, {Map< String, dynamic> inputs = const {}, Map<String, dynamic> scenario = const {}, String? scenarioId}) → Future<EnsembleTestCase> - Loads a test file from disk.
-
parseMocksNode(
dynamic node, {required String testId, required Map< String, dynamic> inputs, required Map<String, dynamic> scenario, String? scenarioId}) → ({List<String> files, Map<String, dynamic> inline}) -
parseString(
String content, {String? sourcePath, Map< String, dynamic> inputs = const {}, Map<String, dynamic> scenario = const {}, String? scenarioId}) → EnsembleTestCase -
Parses one
*.test.yamldocument fromcontent.