EnsembleTestParser class

Constructors

EnsembleTestParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseFile(String path) Future<EnsembleTestCase>
Loads a test file from rootBundle (widget/integration tests) or File (CLI).
parseString(String content, {String? sourcePath}) EnsembleTestCase