AtomicFile class
Replaces a file in one rename operation so readers never see a partial file.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
writeBytesSync(
File target, List< int> bytes) → void -
writeStringSync(
File target, String contents, {Encoding encoding = utf8}) → void