EnsembleTestContext class
Constructors
- EnsembleTestContext({required EnsembleTestCase testCase, required MockAPIProvider mockApiProvider, required TestLogger logger, required EnsembleTestSetup setup})
- EnsembleTestContext.fromTestCase(EnsembleTestCase testCase)
-
factory
Properties
-
envOverrides
→ Map<
String, dynamic> -
Runtime env overrides applied via setEnv steps.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → TestLogger
-
final
- mockApiProvider → MockAPIProvider
-
final
- runtime → TestRuntimeState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setup → EnsembleTestSetup
-
final
- testCase → EnsembleTestCase
-
final
Methods
-
applyRuntimeEnv(
) → void -
clearStorage(
) → Future< void> -
mockFromStepArgs(
Map< String, dynamic> args) → MockAPIResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStorage(
String key) → void -
setEnv(
String key, dynamic value) → void -
setStorage(
String key, dynamic value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited