EnsembleTestHarness class

Boots the real Ensemble runtime for widget tests.

Constructors

EnsembleTestHarness({required String appPath, required String appHome, String? i18nPath, Map<String, Function>? externalMethods})

Properties

appHome String
final
appPath String
final
externalMethods Map<String, Function>?
final
hashCode int
The hash code for this object.
no setterinherited
i18nPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bootstrapRuntime(EnsembleConfig config, EnsembleTestSetup setup, {TestApiProviderOverlay? apiOverlay}) Future<EnsembleConfig>
buildConfig({Locale? forcedLocale}) Future<EnsembleConfig>
loadScreen({required WidgetTester tester, required EnsembleTestCase testCase, EnsembleConfig? existingConfig, EnsembleTestContext? context, EnsembleTestConfig suiteConfig = const EnsembleTestConfig(), Future<void> beforeBootstrap()?, Locale? forcedLocale}) Future<EnsembleConfig>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

applyInPlaceSetup(EnsembleTestContext ctx) Future<void>
ensureAppFontsLoaded() Future<void>
ensureTestPlugins() → void
fontAssetCandidatesForTest(String asset) List<String>
fontFamilyAliasesForTest(String family) List<String>
initializeRealApiProviders(EnsembleConfig config) Future<void>
installTestApiOverlay(EnsembleConfig config, TestApiProviderOverlay mock) → void
Wraps real providers with mock for call recording and optional overrides.
normalizeAppPath(String path) String
openSessionScreen(WidgetTester tester, EnsembleTestCase testCase) Future<void>
packageInfoForTest(String appDir) Map<String, String>
resetTestRuntime() → void
waitForInitialWidgets(WidgetTester tester, {EnsembleTestCase? testCase}) Future<void>