EnsembleTestHarness class

Boots the real Ensemble runtime for widget tests.

Constructors

EnsembleTestHarness({required String appPath, required String appHome, String? i18nPath})

Properties

appHome String
final
appPath String
final
hashCode int
The hash code for this object.
no setterinherited
i18nPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bootstrapRuntime(EnsembleConfig config, EnsembleTestSetup setup, {MockAPIProvider? httpMock}) Future<EnsembleConfig>
buildConfig({Locale? forcedLocale}) Future<EnsembleConfig>
loadScreen({required WidgetTester tester, required EnsembleTestCase testCase, EnsembleConfig? existingConfig, EnsembleTestContext? context}) Future<EnsembleConfig>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

applyInPlaceSetup(EnsembleTestContext ctx) → void
ensureTestPlugins() → void
installHttpMockProvider(EnsembleConfig config, MockAPIProvider mock) → void
normalizeAppPath(String path) String
resetTestRuntime() → void
waitForInitialWidgets(WidgetTester tester, {EnsembleTestCase? testCase}) Future<void>