StorageStepDiff class

Public-storage diff attributed to one top-level step.

Constructors

StorageStepDiff({required int stepIndex, required DateTime timestamp, required List<StorageKeyChange> changes})
const

Properties

changes List<StorageKeyChange>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepIndex int
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited