TestRuntimeState class
Mutable runtime flags and logs for declarative test steps.
Constructors
Properties
-
authUser
↔ Map<
String, dynamic> ? -
getter/setter pair
-
consoleLogs
→ List<
String> -
final
- deviceSize ↔ Size?
-
getter/setter pair
-
fixtures
→ Map<
String, dynamic> -
final
-
flutterErrors
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale ↔ Locale?
-
getter/setter pair
- networkOffline ↔ bool
-
getter/setter pair
-
permissions
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeMode ↔ String?
-
getter/setter pair
Methods
-
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited