YamlTestSession class
Per–widget-test session state for declarative YAML tests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final
- runtimeBootstrapped ↔ bool
-
getter/setter pair
Static Methods
-
dispose(
) → void - End of the widget test (cancels listeners).
-
markRuntimeBootstrapped(
) → void -
reset(
) → void - Between cold starts within a suite (keeps the screen-change listener).